{% extends "base.html" %}

{% block title %}Removed{% endblock %}

{% block content %}
  <h2>{%if object%} {{ object }}{% else %} This item{% endif %} has been removed.</h2>
  {% if object %}
    <a href="{{ object.get_absolute_url }}">Go back</a>
  {% endif %}
{% endblock %}
