{% extends "base.html" %}

{% block title %}Added{% endblock %}

{% block content %}
  <h2>You are now watching {%if object%} {{ object }}{% else %} this item{%endif%}.</h2>
  {% if object %}
    <ul>
      <li><a href="{{ object.get_absolute_url }}">Go back</a></li>
    </ul>
  {% endif %}
{% endblock %}
